===========
Descriptive
===========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    DataFrame.describe
    DataFrame.glimpse
    DataFrame.estimated_size
    DataFrame.is_duplicated
    DataFrame.is_empty
    DataFrame.is_unique
    DataFrame.n_chunks
    DataFrame.n_unique
    DataFrame.null_count
